@@ -54,8 +54,6 @@ sub new {
 			}
 		}
 		$this->{py3vers} =~ s/\s+$//;
-		$this->{pypydef} = `pypy -c 'from sys import pypy_version_info as i; print("%s.%s" % (i.major, i.minor))' 2>/dev/null`;
-		$this->{pypydef} =~ s/\s+$//;
 	}
 
 	return $this;
@@ -152,23 +150,13 @@ sub pybuild_commands {
 			$ENV{'PBR_VERSION'} = $version;
 		}
 
-		my @py2opts = ('pybuild', "--$step");
 		my @py3opts = ('pybuild', "--$step");
-		my @pypyopts = ('pybuild', "--$step");
 
 		if ($step eq 'test' and $ENV{'PYBUILD_TEST_PYTEST'} ne '1' and
 				$ENV{'PYBUILD_TEST_NOSE2'} ne '1' and
 				$ENV{'PYBUILD_TEST_NOSE'} ne '1' and
 				$ENV{'PYBUILD_TEST_CUSTOM'} ne '1' and
 				$ENV{'PYBUILD_TEST_TOX'} ne '1') {
-			if (grep {$_ eq 'python-tox'} @deps and $ENV{'PYBUILD_TEST_TOX'} ne '0') {
-				push @py2opts, '--test-tox'}
-			elsif (grep {$_ eq 'python-pytest'} @deps and $ENV{'PYBUILD_TEST_PYTEST'} ne '0') {
-				push @py2opts, '--test-pytest'}
-			elsif (grep {$_ eq 'python-nose2'} @deps and $ENV{'PYBUILD_TEST_NOSE2'} ne '0') {
-				push @py2opts, '--test-nose2'}
-			elsif (grep {$_ eq 'python-nose'} @deps and $ENV{'PYBUILD_TEST_NOSE'} ne '0') {
-				push @py2opts, '--test-nose'}
 			if (grep {$_ eq 'tox'} @deps and $ENV{'PYBUILD_TEST_TOX'} ne '0') {
 				push @py3opts, '--test-tox'}
 			elsif (grep {$_ eq 'python3-pytest'} @deps and $ENV{'PYBUILD_TEST_PYTEST'} ne '0') {
@@ -177,42 +165,13 @@ sub pybuild_commands {
 				push @py3opts, '--test-nose2'}
 			elsif (grep {$_ eq 'python3-nose'} @deps and $ENV{'PYBUILD_TEST_NOSE'} ne '0') {
 				push @py3opts, '--test-nose'}
-			if (grep {$_ eq 'pypy-tox'} @deps and $ENV{'PYBUILD_TEST_TOX'} ne '0') {
-				push @pypyopts, '--test-tox'}
-			elsif (grep {$_ eq 'pypy-pytest'} @deps and $ENV{'PYBUILD_TEST_PYTEST'} ne '0') {
-				push @pypyopts, '--test-pytest'}
-			elsif (grep {$_ eq 'pypy-nose'} @deps and $ENV{'PYBUILD_TEST_NOSE'} ne '0') {
-				push @pypyopts, '--test-nose'}
 		}
 
-		my $pyall = 0;
-		my $pyalldbg = 0;
 		my $py3all = 0;
 		my $py3alldbg = 0;
 
 		my $i = 'python{version}';
 
-		# Python
-		if ($this->{pyvers}) {
-			if (grep {$_ eq 'python-all' or $_ eq 'python-all-dev'} @deps) {
-				$pyall = 1;
-				push @result, [@py2opts, '-i', $i, '-p', $this->{pyvers}, @options];
-			}
-			if (grep {$_ eq 'python-all-dbg'} @deps) {
-				$pyalldbg = 1;
-				push @result, [@py2opts, '-i', "$i-dbg", '-p', $this->{pyvers}, @options];
-			}
-		}
-		if ($this->{pydef}) {
-			if (not $pyall and grep {$_ eq 'python' or $_ eq 'python-dev' or
-					$_ eq 'python2.7' or $_ eq 'python2.7-dev'} @deps) {
-				push @result, [@py2opts, '-i', $i, '-p', $this->{pydef}, @options];
-			}
-			if (not $pyalldbg and grep {$_ eq 'python-dbg' or $_ eq 'python2.7-dbg'} @deps) {
-				push @result, [@py2opts, '-i', "$i-dbg", '-p', $this->{pydef}, @options];
-			}
-		}
-
 		# Python 3
 		if ($this->{py3vers}) {
 			if (grep {$_ eq 'python3-all' or $_ eq 'python3-all-dev'} @deps) {
@@ -234,10 +193,6 @@ sub pybuild_commands {
 		}
 		# TODO: pythonX.Y → `pybuild -i python{version} -p X.Y`
 
-		# PyPy
-		if ($this->{pypydef} and grep {$_ eq 'pypy'} @deps) {
-			push @result, [@pypyopts, '-i', 'pypy', '-p', $this->{pypydef}, @options];
-		}
 	}
 	if (!@result) {
 		use Data::Dumper;
